@@ -7,6 +7,7 @@ from geneticengine.core.decorators import get_gengy
 from geneticengine.core.grammar import Grammar
 from geneticengine.core.random.sources import Source
 from geneticengine.core.representations.api import Representation
+from geneticengine.core.representations.tree.initialization_methods import Initialization_Method
 from geneticengine.core.representations.tree.treebased import PI_Grow
 from geneticengine.core.representations.tree.treebased import random_node
 from geneticengine.core.tree import TreeNode
@@ -70,9 +71,9 @@ def random_individual(
     r: Source,
     g: Grammar,
     starting_symbol: Any,
-    current_genotype: Genotype = None,
+    current_genotype: Genotype | None = None,
     max_depth: int = 5,
-) -> Genotype:  # This whole method seems cumbersome. Why not just create an empty genotype and let it be sourced through when mapping from genotype to phenotype?
+) -> Genotype: 
     if current_genotype == None:
         nodes = [str(node) for node in g.all_nodes]
         for node in g.all_nodes:
@@ -176,47 +177,17 @@ def random_individual(
     return current_genotype
 
 
-def random_individual_simple(
-    r: Source,
-    g: Grammar,
-    starting_symbol: Any,
-    current_genotype: Genotype = None,
-    max_depth: int = 5,
-) -> Genotype:  # In this method we let the random source use the left_overs to fill up the individual
-    if current_genotype == None:
-        nodes = [str(node) for node in g.all_nodes]
-        for node in g.all_nodes:
-            arguments = get_arguments(node)
-            for _, arg in arguments:
-                if is_generic(arg):
-                    nodes.append(str(arg))
-                base_type = str(strip_annotations(arg))
-                if base_type not in nodes:
-                    nodes.append(base_type)
-
-        dna: dict[str, list[int]] = dict()
-        for nodestr in nodes:
-            dna[nodestr] = list()
-        dna[LEFTOVER_KEY] = [
-            r.randint(0, MAX_RAND_INT) for _ in range(1000)
-        ]  # Necessary to source from when a production rule runs out of genes.
-        current_genotype = Genotype(dna)
-
-    assert type(current_genotype) == Genotype
-    return current_genotype
-
 
 def create_individual(
     r: Source,
     g: Grammar,
     starting_symbol: Any = None,
-    current_genotype: Genotype = None,
+    current_genotype: Genotype | None = None,
     max_depth: int = 5,
 ) -> Genotype:
     if not starting_symbol:
         starting_symbol = g.starting_symbol
 
-    # return random_individual_simple(r, g, starting_symbol, current_genotype, max_depth)
     return random_individual(r, g, starting_symbol, current_genotype, max_depth)
 
 
@@ -295,17 +266,19 @@ class DynamicStructuredListWrapper(Source):
         return 1 * (max - min) / k + min
 
 
-def create_tree(g: Grammar, ind: Genotype, depth: int) -> TreeNode:
+def create_tree(g: Grammar, ind: Genotype, depth: int, method) -> TreeNode:
     rand: Source = DynamicStructuredListWrapper(ind)
-    return random_node(rand, g, depth, g.starting_symbol, method=PI_Grow)
+    return random_node(rand, g, depth, g.starting_symbol, method=method)
 
 
 class DynamicStructuredGrammaticalEvolutionRepresentation(Representation[Genotype]):
     """This version uses a list of lists of integers to represent individuals, based on non-terminal
     symbols. It delays computing the expansions that have enough depth to runtime."""
 
-    depth: int
-
+    def __init__(self, depth = None, method: Initialization_Method = PI_Grow()) -> None:
+        self.depth = depth
+        self.method = method
+    
     def create_individual(self, r: Source, g: Grammar, depth: int) -> Genotype:
         self.depth = depth
         return create_individual(r, g, max_depth=depth)
@@ -317,7 +290,7 @@ class DynamicStructuredGrammaticalEvolutionRepresentation(Representation[Genotyp
         ind: Genotype,
         depth: int,
         ty: type,
-        specific_type: type = None,
+        specific_type: type | None = None,
         depth_aware_mut: bool = False,
     ) -> Genotype:
         return mutate(r, g, ind, depth)
@@ -329,13 +302,13 @@ class DynamicStructuredGrammaticalEvolutionRepresentation(Representation[Genotyp
         i1: Genotype,
         i2: Genotype,
         depth: int,
-        specific_type: type = None,
+        specific_type: type | None = None,
         depth_aware_co: bool = False,
     ) -> tuple[Genotype, Genotype]:
         return crossover(r, g, i1, i2, depth)
 
     def genotype_to_phenotype(self, g: Grammar, genotype: Genotype) -> TreeNode:
-        return create_tree(g, genotype, self.depth)
+        return create_tree(g, genotype, self.depth, self.method.tree_init_method)
 
 
 dsge_representation = DynamicStructuredGrammaticalEvolutionRepresentation()
